﻿
# ask user for output path filename

Function Get-FileName($initialDirectory)
        {   
         [System.Reflection.Assembly]::LoadWithPartialName("System.windows.forms") |
         Out-Null

         $SaveFileDialog = New-Object System.Windows.Forms.SaveFileDialog
         $SaveFileDialog.initialDirectory = $initialDirectory
         $SaveFileDialog.filter = “Zip files (*.zip)|*.zip|All files (*.*)|*.*”
         $SaveFileDialog.DefaultExt = "zip"
        # $SaveFileDialog.AddExtension
         
         $dialogresult = $SaveFileDialog.ShowDialog()

         if( $dialogresult -eq "OK" )
            {
            $SaveFileDialog.filename
            }
        else
            {
            # no valid filenae
            exit
            }
        }
    
    # store filename for use at end
    $Savefile = Get-Filename -initialDirectory "%USERDATA%\desktop\"
        

    # create temp directory in same place as $savefile
    $TempPath = $Savefile
    $TempPath = $TempPath.Substring(0,$TempPath.LastIndexOf('.'))
    Write-Output $TempPath

    New-Item -ItemType directory -Path $TempPath

    

    # get a list of all services
    $services = Get-Service
    
    #

    foreach( $service in $services )
        {
        # work through the services, get the image path
        $SerName = $service.Name
        # Get the path from the service name
        $BinPath =  (Get-ItemProperty -Path "HKLM:\SYSTEM\CurrentControlSet\services\$SerName" ImagePath) | Select ImagePath

        #Write-Output "ImagePath Found: " $BinPath

        # get the path for the service
        $BatPathString = $BinPath.ImagePath
    
        # parse string to remove quotes if they exist
        $pos = $BatPathString.IndexOf("`"")
        $BatPathString = $BatPathString.SubString(($pos+1) )
    
        $pos = $BatPathString.LastIndexOf("`\")
        $BatPathString = $BatPathString.SubString(0,$pos )
    
        $pathtocheck = $BatPathString
        $pathtocheck += "\a5backup.properties"

        #Write-Output $pathtocheck
 
 

        # check if the installation is a valid Attix5 installation by looking for a5backup.properties
        if( Test-Path $pathtocheck  )
            {
    
            # if the a5backup.properties exists, must be an Attix5 service
            # open the a5backup.properties file
            $propsfile = Get-Content $pathtocheck
            # find the logs path
            #Write-Output $propsfile

        
            # define dest path based on service name
        
            $DestRootPath = $TempPath        
            $DestRootPath += "`\"
            
            $DestRootPath += $SerName

            # create path if it doesn't exist
            New-Item  -ItemType Directory -Force -Path $DestRootPath 
        
            #################
            # copy all the required support bundle files to the temp path
            #################

            # get the properties files
            $propstring = $BatPathString
            $propstring += "\*.properties"

        
            # copy properties files to target
            Copy-Item $propstring -Destination $DestRootPath -Force -Exclude "connection.properties"



            # get the xml files
            $xmlstring = $BatPathString
            $xmlstring += "\*.xml"
        
        
            # copy xml to target
            Copy-Item $xmlstring -Destination $DestRootPath -Force 


            # get the backupservice files
            $bslogstring = $BatPathString
            $bslogstring += "\backupservice*"

            # copy backup service to target
            Copy-Item $bslogstring -Destination $DestRootPath -Force 

        
    
            #define log path default
            $SElogpath = $BatPathString
            $SElogpath += "\logs\"

            # flag to mark logs as found
            $foundlogs = "false"

            # if the default SE logs path exists, copy the logs
            if( Test-Path $SElogpath )
                {
                $foundlogs = "true"
                Copy-Item $SElogpath -Destination $DestRootPath -Recurse -Force 
                }
            
    
            if( $foundlogs -eq "false" )
            
                {               
                    
                # now look for customised paths
    
                foreach ($line in $propsfile )
                    {
                
                    #  Write-Output "Line: " $line
                    if( $line -like '*log.dir*' )
                        {
                        $foundpath = $line
                        $pos = $foundpath.IndexOf("=")
                        $foundpath = $foundpath.Substring($pos +1)
                        #Write-Output $foundpath
                        $foundpath = $foundpath.Replace('\\', '\')
                        $foundpath = $foundpath.Replace('\:',':')
                        #Write-Output $foundpath
                        
                        $foundpath += "\"
    
                        Copy-Item $foundpath -Destination $DestRootPath -Recurse -Force 
                        $foundlogs = "true"
                        break
                        }         
                            
                    }
                # going to check through the setup.properties file as well as installation may not be default
                if( $foundlogs -eq "false" )
                    {
                    $setupfilepath = $BatPathString
                    $setupfilepath += "\setup.properties"
                    if( Test-Path $setupfilepath )
                        {
                        $setupfile = Get-Content -Path $setupfilepath

                        foreach( $line in $setupfile )
                            {

                            if( $line -like "shared.program.data.dir=*" )
                                {
                                $foundpath = $line
                                $pos = $foundpath.IndexOf("=")
                                $foundpath = $foundpath.Substring($pos +1)
                                #Write-Output $foundpath
                                $foundpath = $foundpath.Replace('\\', '\')
                                $foundpath = $foundpath.Replace('\:',':')
                                #Write-Output $foundpath
                        
                                $psprogdata = [Environment]::GetFolderPath("CommonApplicationData")
                
                                $foundpath = $foundpath -Replace "%ProgramData%", $psprogdata

                                $foundpath += "\logs\"
    
			                    Copy-Item $foundpath -Destination $DestRootPath -Recurse -Force 
        	                    $foundlogs = "true"
                                break
                                }
                            }
                        }
                    }



                if( $foundlogs -eq "false" )
                    {
                    # not found anything, probably an ESE service using defaults
                    # try copying the default paths
                    $defA5BPESE = "C:\ProgramData\Attix5 Pro\Backup Client ESE\logs\"

                    if( Test-Path $defA5BPESE )
                        {
                        # copy the logs to a destination directory
                        Copy-Item $defA5BPESE -Destination $DestRootPath -Recurse -Force 
                        }
                    
                    $defROBESE = "C:\ProgramData\Redstor Online Backup\Backup Client ESE\logs\"
                    
                    if( Test-Path $defROBESE )
                        {
                        # copy the logs to a destination directory
                        Copy-Item $defROBESE -Destination $DestRootPath -Recurse -Force 
                        }
                    
                    
                    }
    
                
                }
            
            }
        
        }

    # now zip up the temporary path
    Add-Type -assembly "system.io.compression.filesystem"
    [io.compression.zipfile]::CreateFromDirectory($TempPath, $Savefile)

    # cleanup source files
    Remove-Item $TempPath -Recurse -force
